-- debug_status = 1
debug_mod_name = "Empty"
debug_file = debug_mod_name .. "-debug.txt"
require("utils")

--------------------------------------------------------------------------------------
function init_globals()
	-- initialize or update general globals of the mod
	global.ticks = global.ticks or 0
	global.player_mem = global.player_mem or {}
end

--------------------------------------------------------------------------------------
script.on_init( 
	-- called once, the first time the mod is loaded on a game (new or existing game)
	function()
		debug_print( "on_init" )
		init_globals()
	end
)

--------------------------------------------------------------------------------------
local function init_player(player)
	if player.gui.top.frm_empty then player.gui.top.frm_empty.destroy() end
	build_gui(player)
end

--------------------------------------------------------------------------------------
function init_players()
	for _, player in pairs(game.players) do
		init_player(player)
	end
end

--------------------------------------------------------------------------------------
function on_configuration_changed(data)
	-- detect any mod or game version change
	if data.mod_changes ~= nil then
		local changes = data.mod_changes[debug_mod_name]
		if changes ~= nil then
			debug_print( "update mod: ", debug_mod_name, " ", tostring(changes.old_version), " to ", tostring(changes.new_version) )
		
			init_globals()
			
			init_players()
		end
	end
end

script.on_configuration_changed(on_configuration_changed)

--------------------------------------------------------------------------------------
function on_player_created(event)
	-- called at player creation
	local player = game.players[event.player_index]
	debug_print( "player created ", player.name )
	
	init_player(player)
end

script.on_event(defines.events.on_player_created, on_player_created )

--------------------------------------------------------------------------------------
function on_gui_text_changed(event)
	local player = game.players[event.player_index]
	local event_name = event.element.name
	
	if event_name == "txt_test" then
		player.print( player.gui.top.frm_empty.txt_test.text )
	end
end

script.on_event(defines.events.on_gui_text_changed, on_gui_text_changed)

--------------------------------------------------------------------------------------
function build_gui( player )
	-- here only build gui, but not try to update it with player data that is not always already available (in init_player for example)
	local guif = player.gui.top.frm_empty
	
	if guif == nil then
		debug_print("create gui player" .. player.name)
		guif = player.gui.top.add({type = "frame", name = "frm_empty", caption = "Empty", direction = "horizontal", style = "empty_frame_style"})
		guif.add({type = "textfield", name = "txt_test", caption = "Test", style = "textfield_style"})				
	end
end
	

